# frozen_string_literal: true

#
# Copyright (c) 2015-2017 Sam4Mobile, 2017-2018 Make.org, 2019 Samuel Bernard
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# rubocop:disable Metrics/BlockLength

property :config, String, default: '/etc/gitlab-runner/config.toml'
property :concurrent, Integer
property :log_level, String
property :log_format, String
property :check_interval, Integer
property :sentry_dsn, [true, false]
property :listen_address, String
property :options, Hash

action :set do
  extend GitlabCiRunner::RunnerHelpers

  config = toml_parse(new_resource.config)
  %i[
    concurrent
    log_level
    log_format
    check_interval
    sentry_dsn
    listen_address
  ].each do |key|
    next if new_resource.send(key).nil?
    next if config[key.to_s].eql?(new_resource.send(key))

    converge_by("Updating global setting #{key}") do
      config[key.to_s] = new_resource.send(key)
    end
  end

  unless new_resource.options.nil? || new_resource.options.empty?
    config.merge(new_resource.options)
  end

  config = compact_hash(config)

  unless toml_parse(new_resource.config).eql?(config)
    converge_by("Updating configuration file #{new_resource.config}") do
      file new_resource.config do
        content toml_generate(config)
        owner 'root'
        group 'root'
        mode '0600'
        sensitive true
        action :create
        notifies :restart, 'service[gitlab-runner]', :delayed
      end
    end
  end
end

# rubocop:enable Metrics/BlockLength
